@@ -69,7 +69,6 @@ BASE_SWAGGER_SETTINGS = {
         # 'vng_api_common.inspectors.geojson.GeometryFieldInspector',
         "vng_api_common.inspectors.fields.HyperlinkedIdentityFieldInspector",
         "vng_api_common.inspectors.fields.ReadOnlyFieldInspector",
-        "vng_api_common.inspectors.fields.JSONFieldInspector",
         "vng_api_common.inspectors.polymorphic.PolymorphicSerializerInspector",
         "vng_api_common.inspectors.fields.GegevensGroepInspector",
         "drf_yasg.inspectors.CamelCaseJSONFilter",
@@ -78,8 +77,10 @@ BASE_SWAGGER_SETTINGS = {
         "drf_yasg.inspectors.ChoiceFieldInspector",
         "drf_yasg.inspectors.FileFieldInspector",
         "drf_yasg.inspectors.DictFieldInspector",
+        "drf_yasg.inspectors.JSONFieldInspector",
         "drf_yasg.inspectors.HiddenFieldInspector",
         "drf_yasg.inspectors.RelatedFieldInspector",
+        "drf_yasg.inspectors.SerializerMethodFieldInspector",
         "drf_yasg.inspectors.SimpleFieldInspector",
         "drf_yasg.inspectors.StringDefaultFieldInspector",
     ),
