@@ -11,10 +11,8 @@ VERSION_HEADER = "API-version"
 
 SCOPE_NOTIFICATIES_PUBLICEREN_LABEL = "notificaties.scopes.publiceren"
 
-# see https://docs.nlx.io/further-reading/transaction-logs/
-HEADER_APPLICATION = "X-NLX-Request-Application-Id"
-HEADER_USER_ID = "X-NLX-Request-User-Id"
 HEADER_AUDIT = "X-Audit-Toelichting"
+HEADER_LOGRECORD_ID = "X-NLX-Logrecord-ID"
 
 FILTER_URL_DID_NOT_RESOLVE = "NO_MATCHING_OBJECT"
 
@@ -289,13 +287,14 @@ class ZaakobjectTypes(DjangoChoices):
 
 
 class ComponentTypes(DjangoChoices):
-    ac = ChoiceItem("ac", "Autorisatiecomponent")
-    nrc = ChoiceItem("nrc", "Notificatierouteringcomponent")
-    zrc = ChoiceItem("zrc", "Zaakregistratiecomponent")
-    ztc = ChoiceItem("ztc", "Zaaktypecatalogus")
-    drc = ChoiceItem("drc", "Documentregistratiecomponent")
-    brc = ChoiceItem("brc", "Besluitregistratiecomponent")
-    kic = ChoiceItem("kic", "Klantinteractiescomponent")
+    ac = ChoiceItem("ac", "Autorisaties API")
+    nrc = ChoiceItem("nrc", "Notificaties API")
+    zrc = ChoiceItem("zrc", "Zaken API")
+    ztc = ChoiceItem("ztc", "Catalogi API")
+    drc = ChoiceItem("drc", "Documenten API")
+    brc = ChoiceItem("brc", "Besluiten API")
+    cmc = ChoiceItem("cmc", "Contactmomenten API")
+    kc = ChoiceItem("kc", "Klanten API")
 
 
 class CommonResourceAction(DjangoChoices):
