@@ -3,5 +3,5 @@ from django.urls import path
 from .views import NotificationView
 
 urlpatterns = [
-    path('callbacks', NotificationView.as_view(), name='notificaties-webhook'),
+    path("callbacks", NotificationView.as_view(), name="notificaties-webhook")
 ]
